API docs for “spamfighter.interfaces.IModel”

# Class s.i.IModel(Interface):

Part of spamfighter.interfaces View Source View In Hierarchy

Интерфейс модели анализа сообщений.

Method | train | Обучить модель на указанном тексте.
Method | classify | Классифицировать текст согласно модели.

def train(text, good): (source)
Обучить модель на указанном тексте.

Parameters | text | текст, на котором обучаемся (type: `unicode` )
| good | хороший это текст или плохой с точки зрения классификации? (type: `bool` )
Returns | результат операции (type: `Deferred` )

def classify(text): (source)
Классифицировать текст согласно модели.

Результат классификации - текст "хороший" или "плохой" (относительно модели).

Parameters | text | текст, который классифируем (type: `unicode` )
Returns | результат операции, `bool`, хороший ли текст? (type: `Deferred` )